"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useCard = void 0;
var _reactNativeReanimated = require("react-native-reanimated");
var _context = require("../../context");
var _card = require("./card.constant");
var _card2 = require("./card.type");
const useCard = _ref => {
  let {
    props
  } = _ref;
  const {
    styles
  } = (0, _context.useMiUiContext)();
  const {
    width = _card.CardConstant.default.width,
    height = _card.CardConstant.default.height,
    backgroundColor = _card.CardConstant.default.backgroundColor,
    cardRadius = _card.CardConstant.default.cardRadius,
    borderWidth = _card.CardConstant.default.borderWidth,
    borderColors = _card.CardConstant.default.borderColors,
    blur = _card.CardConstant.default.blur,
    animation = _card.CardConstant.default.animation,
    animateBorder = _card.CardConstant.default.animateBorder,
    style,
    duration = _card.CardConstant.default.duration
  } = props;
  const canvasPadding = _card.CardConstant.default.padding;
  const CARD_WIDTH = width - borderWidth;
  const CARD_HEIGHT = height - borderWidth;
  const rotateX = (0, _reactNativeReanimated.useSharedValue)(0);
  const rotateY = (0, _reactNativeReanimated.useSharedValue)(0);
  const scale = (0, _reactNativeReanimated.useSharedValue)(1);
  const rotatePoint = (0, _reactNativeReanimated.useSharedValue)(0);
  const zIndex = _card.CardConstant.default.perspective;
  const cardStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    const rotateXValue = `${rotateX.value}deg`;
    const rotateYValue = `${rotateY.value}deg`;
    const scaleValue = scale.value;
    return {
      transform: [{
        perspective: _card.CardConstant.default.perspective
      }, {
        rotateX: rotateXValue
      }, {
        rotateY: rotateYValue
      }, {
        scale: scaleValue
      }]
    };
  }, [rotateX.value, rotateY.value, scale.value]);
  (0, _reactNativeReanimated.useDerivedValue)(() => {
    if (animation !== _card2.AnimationType.none) {
      if (rotatePoint.value === 0) {
        rotatePoint.value = (0, _reactNativeReanimated.withTiming)(1, {
          duration: _card.CardConstant.duration.rotationDuration,
          easing: _reactNativeReanimated.Easing.linear
        });
      } else if (rotatePoint.value === 1) {
        rotatePoint.value = (0, _reactNativeReanimated.withTiming)(2, {
          duration: _card.CardConstant.duration.rotationDuration,
          easing: _reactNativeReanimated.Easing.linear
        });
      } else if (rotatePoint.value === 2) {
        rotatePoint.value = (0, _reactNativeReanimated.withTiming)(3, {
          duration: _card.CardConstant.duration.rotationDuration,
          easing: _reactNativeReanimated.Easing.linear
        });
      } else if (rotatePoint.value === 3) {
        rotatePoint.value = (0, _reactNativeReanimated.withTiming)(0, {
          duration: _card.CardConstant.duration.rotationDuration3,
          easing: _reactNativeReanimated.Easing.linear
        });
      }
    }
    if (animation === _card2.AnimationType.rotate) {
      rotateX.value = (0, _reactNativeReanimated.interpolate)(rotatePoint.value, [0, 1, 2, 3, 4], [6, 6, -6, -6], _reactNativeReanimated.Extrapolate.CLAMP);
      rotateY.value = (0, _reactNativeReanimated.interpolate)(rotatePoint.value, [0, 1, 2, 3, 4], [-6, 6, 6, -6], _reactNativeReanimated.Extrapolate.CLAMP);
    } else if (animation === _card2.AnimationType.bounce) {
      rotateX.value = (0, _reactNativeReanimated.withTiming)(0, {
        duration: _card.CardConstant.duration.rotationDuration1,
        easing: _reactNativeReanimated.Easing.bounce
      });
      rotateY.value = (0, _reactNativeReanimated.withTiming)(0, {
        duration: _card.CardConstant.duration.rotationDuration1,
        easing: _reactNativeReanimated.Easing.bounce
      });
      scale.value = (0, _reactNativeReanimated.interpolate)(rotatePoint.value, [0, 1, 2, 3, 4], [1, 1.05, 0.98, 1.05], _reactNativeReanimated.Extrapolate.CLAMP);
    } else {
      rotateX.value = (0, _reactNativeReanimated.withTiming)(0, {
        duration: _card.CardConstant.duration.rotationDuration1,
        easing: _reactNativeReanimated.Easing.linear
      });
      rotateY.value = (0, _reactNativeReanimated.withTiming)(0, {
        duration: _card.CardConstant.duration.rotationDuration1,
        easing: _reactNativeReanimated.Easing.linear
      });
      scale.value = (0, _reactNativeReanimated.withTiming)(1, {
        duration: _card.CardConstant.duration.rotationDuration1,
        easing: _reactNativeReanimated.Easing.linear
      });
    }
  }, [rotatePoint.value, animation]);
  return {
    animateBorder,
    animation,
    backgroundColor,
    blur,
    borderColors,
    borderWidth,
    canvasPadding,
    CARD_HEIGHT,
    CARD_WIDTH,
    cardRadius,
    cardStyle,
    duration,
    height,
    props,
    style,
    styles,
    width,
    zIndex
  };
};
exports.useCard = useCard;
//# sourceMappingURL=useCard.js.map