"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useCircularProgress = void 0;
var _reactNativeSkia = require("@shopify/react-native-skia");
var _context = require("../../context");
var _themes = require("../../themes");
const CONTAINER_SIZE = 250;
const CONTAINER_ELEVATION = 8;
const PROGRESS_FONT_SIZE = 32;
const PADDING = 24;
const CIRCLE_PROGRESS = 25;
const CIRCLE_RADIUS = 100;
const SHADOW_OPACITY = 0.6;
const SHADOW_RADIUS = 10;
const SHADOW_WIDTH = 15;
const ARC_DEGREE = 270;
const ANIM_DURATION = 3000;
const useCircularProgress = props => {
  const {
    styles
  } = (0, _context.useMiUiContext)();
  const {
    backgroundColor = _themes.miColor.circleBackground,
    colors = [_themes.miColor.blueShade, _themes.miColor.greenShade],
    containerSize = CONTAINER_SIZE,
    elevation = CONTAINER_ELEVATION,
    fontSize = PROGRESS_FONT_SIZE,
    gradientColors = [_themes.miColor.blackShade, _themes.miColor.darkGrayShade],
    padding = PADDING,
    progress = CIRCLE_PROGRESS,
    radius = CIRCLE_RADIUS,
    shadowColor = _themes.miColor.purple,
    shadowOffset = {
      height: 4,
      width: 0
    },
    shadowOpacity = SHADOW_OPACITY,
    shadowRadius = SHADOW_RADIUS,
    strokeWidth = SHADOW_WIDTH
  } = props;
  const size = containerSize;
  const viewWidth = size;
  const path = _reactNativeSkia.Skia.Path.Make();
  path.moveTo(strokeWidth, viewWidth / 2 - 50);
  path.addArc({
    height: radius * 2,
    width: radius * 2,
    x: 0,
    y: 0
  }, ARC_DEGREE, progress / 100 * 360);
  const fromCircle = (cx, cy, r) => (0, _reactNativeSkia.rrect)((0, _reactNativeSkia.rect)(cx - r, cy - r, 2 * r, 2 * r), r, r);
  const fillProgress = (0, _reactNativeSkia.useTiming)({
    from: 0,
    to: progress
  }, {
    duration: ANIM_DURATION,
    easing: _reactNativeSkia.Easing.circle
  });
  return {
    backgroundColor,
    colors,
    elevation,
    fillProgress,
    fontSize,
    fromCircle,
    gradientColors,
    padding,
    path,
    progress,
    props,
    radius,
    shadowColor,
    shadowOffset,
    shadowOpacity,
    shadowRadius,
    size,
    strokeWidth,
    styles,
    viewWidth
  };
};
exports.useCircularProgress = useCircularProgress;
//# sourceMappingURL=useCircularProgressBar.js.map