"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useNeoPopButton = void 0;
var _react = require("react");
var _reactNativeSkia = require("@shopify/react-native-skia");
var _reactNativeReanimated = require("react-native-reanimated");
var _context = require("../../context");
var _neoPopButton = require("./neoPopButton.constant");
const useNeoPopButton = props => {
  const {
    styles
  } = (0, _context.useMiUiContext)();
  const {
    backgroundColor: bgColor = _neoPopButton.NeoPopButtonConstant.default.backgroundColor,
    bottomShadowColor = _neoPopButton.NeoPopButtonConstant.default.bottomShadowColor,
    depth = _neoPopButton.NeoPopButtonConstant.default.depth,
    height: propHeight = _neoPopButton.NeoPopButtonConstant.default.height,
    isFloating = _neoPopButton.NeoPopButtonConstant.default.isFloating,
    shadowHeight = _neoPopButton.NeoPopButtonConstant.default.shadowHeight,
    sideShadowColor: bottomSdColor = _neoPopButton.NeoPopButtonConstant.default.sideShadowColor,
    textStyle,
    title = _neoPopButton.NeoPopButtonConstant.default.title,
    width: propWidth = _neoPopButton.NeoPopButtonConstant.default.width,
    titleSize = _neoPopButton.NeoPopButtonConstant.default.titleSize,
    floatAnimation = _neoPopButton.NeoPopButtonConstant.default.floatAnimation,
    duration = _neoPopButton.NeoPopButtonConstant.default.duration,
    disabled = false
  } = props;
  let height = propHeight * 1.5;
  let width = propWidth * 1.5;
  const [shadowTranslate, setShadowTranslate] = (0, _react.useState)(0);
  const [pressed, setPressed] = (0, _react.useState)(false);
  const backgroundColor = disabled ? 'darkgray' : bgColor;
  const sideShadowColor = disabled ? 'gray' : bottomSdColor;
  const translate = (0, _reactNativeSkia.useTiming)({
    from: 0,
    loop: true,
    to: floatAnimation && !disabled ? 11 : 0,
    yoyo: true
  }, {
    duration: duration,
    easing: _reactNativeSkia.Easing.linear
  });
  const translateY = (0, _reactNativeSkia.useValue)(0);
  const shadowPath = _reactNativeSkia.Skia.Path.Make();
  shadowPath.moveTo(25, height - shadowHeight);
  shadowPath.lineTo(22, height + shadowTranslate);
  shadowPath.lineTo(width - 20, height + shadowTranslate);
  shadowPath.lineTo(width - 24, height - shadowHeight);
  const path = _reactNativeSkia.Skia.Path.Make();
  path.moveTo(0, height - depth - shadowHeight);
  path.lineTo(width, height - depth - shadowHeight);
  path.lineTo(width - 25, 0);
  path.lineTo(25, 1);
  path.close();
  const path2 = _reactNativeSkia.Skia.Path.Make();
  path2.moveTo(0, height - depth - shadowHeight);
  path2.lineTo(15, height - depth - shadowHeight);
  path2.lineTo(35, 0);
  path2.lineTo(25, 0);
  path2.close();
  const depthPath = _reactNativeSkia.Skia.Path.Make();
  depthPath.moveTo(0, height - depth - shadowHeight);
  depthPath.lineTo(6, height - depth - shadowHeight + depth);
  depthPath.lineTo(width - 6, height - depth - shadowHeight + depth);
  depthPath.lineTo(width, height - depth - shadowHeight);
  const depthPath2 = _reactNativeSkia.Skia.Path.Make();
  depthPath2.moveTo(0, height);
  depthPath2.lineTo(25, 100);
  depthPath2.lineTo(35, 0);
  depthPath2.lineTo(25, 45);
  depthPath2.close();
  const nonFloatingDepthPath = _reactNativeSkia.Skia.Path.Make();
  nonFloatingDepthPath.moveTo(0, height - depth - shadowHeight);
  nonFloatingDepthPath.lineTo(6, height - depth - shadowHeight + depth - translate.current);
  nonFloatingDepthPath.lineTo(width - 6, height - depth - shadowHeight + depth - translate.current);
  nonFloatingDepthPath.lineTo(width, height - depth - shadowHeight);
  const onPressStart = () => {
    setPressed(true);
    translateY.current = isFloating ? shadowHeight : depth;
    setShadowTranslate(-shadowHeight);
  };
  const onPressEnd = () => {
    setPressed(false);
    translateY.current = 0;
    setShadowTranslate(0);
  };
  const textTransform = (0, _reactNativeReanimated.useSharedValue)(0);
  const transform = (0, _reactNativeSkia.useComputedValue)(() => {
    textTransform.value = translate.current;
    return [{
      translateY: pressed || disabled ? 10 : !floatAnimation ? 0 : translate.current
    }];
  }, [translate, pressed, floatAnimation, disabled]);
  const textTransformStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    return {
      transform: [{
        translateY: pressed || disabled ? 0 : textTransform.value - 12
      }, {
        rotateX: '45deg'
      }, {
        rotateZ: '0deg'
      }]
    };
  }, [textTransform, pressed, disabled]);
  return {
    backgroundColor,
    bottomShadowColor,
    depth,
    depthPath,
    depthPath2,
    disabled,
    floatAnimation,
    height,
    isFloating,
    nonFloatingDepthPath,
    onPressEnd,
    onPressStart,
    path,
    path2,
    pressed,
    props,
    shadowHeight,
    shadowPath,
    shadowTranslate,
    sideShadowColor,
    styles,
    textStyle,
    textTransformStyle,
    title,
    titleSize,
    transform,
    translate,
    width
  };
};
exports.useNeoPopButton = useNeoPopButton;
//# sourceMappingURL=useNeoPopButton.js.map