"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useStarWarButton = void 0;
var _react = require("react");
var _reactNativeSkia = require("@shopify/react-native-skia");
var _reactNativeReanimated = require("react-native-reanimated");
var _context = require("../../context");
var _starWarButton = require("./starWarButton.constant");
var _starWarButton2 = require("./starWarButton.type");
const useStarWarButton = props => {
  const {
    styles
  } = (0, _context.useMiUiContext)();
  const scale = (0, _reactNativeReanimated.useSharedValue)(1);
  const opacity = (0, _reactNativeReanimated.useSharedValue)(1);
  const {
    style,
    gradientType = _starWarButton.StarWarButtonConstant.default.gradientType,
    filled = _starWarButton.StarWarButtonConstant.default.filled,
    textStyle,
    titleSize = _starWarButton.StarWarButtonConstant.default.titleSize,
    title = _starWarButton.StarWarButtonConstant.default.title,
    width = _starWarButton.StarWarButtonConstant.default.width,
    height = _starWarButton.StarWarButtonConstant.default.height,
    blurRadius = _starWarButton.StarWarButtonConstant.default.blurRadius,
    buttonBorderRadius = _starWarButton.StarWarButtonConstant.default.buttonBorderRadius,
    titleColor = _starWarButton.StarWarButtonConstant.default.titleColor,
    animation = _starWarButton.StarWarButtonConstant.default.animation,
    backgroundColor = _starWarButton.StarWarButtonConstant.default.backgroundColor,
    animationDuration = _starWarButton.StarWarButtonConstant.default.animationDuration,
    buttonEffectDuration = _starWarButton.StarWarButtonConstant.default.buttonEffectDuration
  } = props;
  const buttonWidth = width;
  const buttonHeight = height;
  const canvasButtonWidth = buttonWidth + _starWarButton.StarWarButtonConstant.default.buttonPadding;
  const canvasButtonHeight = buttonHeight + _starWarButton.StarWarButtonConstant.default.buttonPadding;
  const canvasPadding = _starWarButton.StarWarButtonConstant.default.canvasPadding;
  const CANVAS_WIDTH = canvasButtonWidth + canvasPadding;
  const CANVAS_HEIGHT = canvasButtonHeight + canvasPadding;
  const colors = (0, _react.useMemo)(() => Array.isArray(props.colors) ? props.colors : [props.colors], [props.colors]);
  const gradient = (0, _react.useMemo)(() => {
    if (props.gradientType === _starWarButton2.GradientType.sweep) {
      return {
        center: props.center ? props.center : {
          x: CANVAS_WIDTH / 2,
          y: CANVAS_HEIGHT / 2
        }
      };
    }
    if (props.gradientType === _starWarButton2.GradientType.radial) {
      return {
        center: props.center ? props.center : {
          x: CANVAS_WIDTH / 2,
          y: CANVAS_HEIGHT / 2
        },
        radius: props.radius ? props.radius : 150
      };
    }
    if (props.gradientType === _starWarButton2.GradientType.linear) {
      return {
        end: props.end ? props.end : {
          x: 0,
          y: CANVAS_HEIGHT / 2
        },
        start: props.start ? props.start : {
          x: CANVAS_WIDTH / 2,
          y: CANVAS_WIDTH / 2
        }
      };
    }
    return;
  }, [CANVAS_HEIGHT, CANVAS_WIDTH, props.center, props.end, props.gradientType, props.radius, props.start]);
  const rotate = (0, _reactNativeSkia.useTiming)({
    from: _starWarButton.StarWarButtonConstant.default.rotateValueFrom,
    loop: true,
    to: _starWarButton.StarWarButtonConstant.default.rotateValueTo
  }, {
    duration: animationDuration,
    easing: _reactNativeReanimated.Easing.linear
  });
  const transform = (0, _reactNativeSkia.useComputedValue)(() => [{
    rotate: rotate.current
  }], [rotate]);
  const scaledButton = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    return {
      perspective: _starWarButton.StarWarButtonConstant.default.perspective,
      transform: [{
        scale: scale.value
      }]
    };
  }, [scale.value, opacity.value]);
  const opacityButton = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    return {
      opacity: opacity.value
    };
  }, [opacity]);
  const transformAnimation = animation ? transform : undefined;
  const onPressStart = (0, _react.useCallback)(() => {
    scale.value = (0, _reactNativeReanimated.withTiming)(0.85, {
      duration: buttonEffectDuration,
      easing: _reactNativeReanimated.Easing.linear
    });
    opacity.value = (0, _reactNativeReanimated.withTiming)(0, {
      duration: buttonEffectDuration,
      easing: _reactNativeReanimated.Easing.linear
    });
  }, [buttonEffectDuration, opacity, scale]);
  const onPressEnd = (0, _react.useCallback)(() => {
    scale.value = (0, _reactNativeReanimated.withTiming)(1, {
      duration: buttonEffectDuration,
      easing: _reactNativeReanimated.Easing.linear
    });
    opacity.value = (0, _reactNativeReanimated.withTiming)(1, {
      duration: buttonEffectDuration,
      easing: _reactNativeReanimated.Easing.linear
    });
  }, [buttonEffectDuration, opacity, scale]);
  return {
    animation,
    backgroundColor,
    blurRadius,
    buttonBorderRadius,
    CANVAS_HEIGHT,
    CANVAS_WIDTH,
    canvasButtonHeight,
    canvasButtonWidth,
    canvasPadding,
    colors,
    filled,
    gradient,
    gradientType,
    height,
    onPressEnd,
    onPressStart,
    opacity,
    opacityButton,
    progress: rotate,
    props,
    scale,
    scaledButton,
    style,
    styles,
    textStyle,
    title,
    titleColor,
    titleSize,
    transform,
    transformAnimation,
    width
  };
};
exports.useStarWarButton = useStarWarButton;
//# sourceMappingURL=useStarWarButton.js.map