import React from 'react';
import { Pressable, Text } from 'react-native';
import { BlurMask, Canvas, LinearGradient, RadialGradient, RoundedRect, SweepGradient, vec } from '@shopify/react-native-skia';
import Animated from 'react-native-reanimated';
import { GradientType } from './starWarButton.type';
import { useStarWarButton } from './useStarWarButton';
const AnimatedPressable = Animated.createAnimatedComponent(Pressable);
export const StarWarButtonComponent = /*#__PURE__*/React.memo(props => {
  var _gradient$center, _gradient$center2, _gradient$center3, _gradient$center4, _gradient$start, _gradient$start2, _gradient$end, _gradient$end2;
  const {
    blurRadius,
    buttonBorderRadius,
    canvasButtonHeight,
    canvasButtonWidth,
    canvasPadding,
    colors,
    filled,
    gradientType,
    styles,
    textStyle,
    title,
    titleColor,
    titleSize,
    style,
    scaledButton,
    transformAnimation,
    gradient,
    backgroundColor,
    opacityButton,
    onPressEnd,
    onPressStart,
    CANVAS_HEIGHT,
    CANVAS_WIDTH
  } = useStarWarButton(props);
  return /*#__PURE__*/React.createElement(AnimatedPressable, {
    style: [styles.starWarButtonStyle.container || {}, scaledButton],
    onPress: props.onPress,
    onLongPress: props.onLongPress,
    onPressIn: onPressStart,
    onPressOut: onPressEnd
  }, /*#__PURE__*/React.createElement(Canvas, {
    style: [{
      height: CANVAS_HEIGHT,
      width: CANVAS_WIDTH
    }],
    children: /*#__PURE__*/React.createElement(RoundedRect, {
      x: canvasPadding / 2,
      y: canvasPadding / 2,
      height: canvasButtonHeight,
      width: canvasButtonWidth,
      r: buttonBorderRadius
    }, gradientType === GradientType.sweep && /*#__PURE__*/React.createElement(SweepGradient, {
      origin: vec(CANVAS_WIDTH / 2, CANVAS_HEIGHT / 2),
      c: vec(gradient === null || gradient === void 0 ? void 0 : (_gradient$center = gradient.center) === null || _gradient$center === void 0 ? void 0 : _gradient$center.x, gradient === null || gradient === void 0 ? void 0 : (_gradient$center2 = gradient.center) === null || _gradient$center2 === void 0 ? void 0 : _gradient$center2.y),
      colors: colors,
      transform: transformAnimation
    }), gradientType === GradientType.radial && /*#__PURE__*/React.createElement(RadialGradient, {
      origin: vec(CANVAS_WIDTH / 2, CANVAS_HEIGHT / 2),
      c: vec(gradient === null || gradient === void 0 ? void 0 : (_gradient$center3 = gradient.center) === null || _gradient$center3 === void 0 ? void 0 : _gradient$center3.x, gradient === null || gradient === void 0 ? void 0 : (_gradient$center4 = gradient.center) === null || _gradient$center4 === void 0 ? void 0 : _gradient$center4.y),
      r: gradient === null || gradient === void 0 ? void 0 : gradient.radius,
      colors: colors,
      transform: transformAnimation
    }), gradientType === GradientType.linear && /*#__PURE__*/React.createElement(LinearGradient, {
      origin: vec(CANVAS_WIDTH / 2, CANVAS_HEIGHT / 2),
      start: vec(gradient === null || gradient === void 0 ? void 0 : (_gradient$start = gradient.start) === null || _gradient$start === void 0 ? void 0 : _gradient$start.x, gradient === null || gradient === void 0 ? void 0 : (_gradient$start2 = gradient.start) === null || _gradient$start2 === void 0 ? void 0 : _gradient$start2.y),
      end: vec(gradient === null || gradient === void 0 ? void 0 : (_gradient$end = gradient.end) === null || _gradient$end === void 0 ? void 0 : _gradient$end.x, gradient === null || gradient === void 0 ? void 0 : (_gradient$end2 = gradient.end) === null || _gradient$end2 === void 0 ? void 0 : _gradient$end2.y),
      colors: colors,
      transform: transformAnimation
    }), /*#__PURE__*/React.createElement(BlurMask, {
      blur: blurRadius,
      style: filled
    }))
  }), /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.cardStyle.card, styles.starWarButtonStyle.buttonTextView, {
      backgroundColor: backgroundColor,
      borderRadius: buttonBorderRadius,
      height: canvasButtonHeight,
      width: canvasButtonWidth
    }, opacityButton, style]
  }, /*#__PURE__*/React.createElement(Text, {
    style: [{
      color: titleColor,
      fontSize: titleSize
    }, textStyle && {
      ...textStyle
    }]
  }, title)));
});
//# sourceMappingURL=starWarButton.js.map